@@ -36,7 +36,7 @@ func NewTestCmd(globalCfg *config.GlobalImpl) *cobra.Command {
 	f.BoolVar(&testOptions.SkipDeps, "skip-deps", false, `skip running "helm repo update" and "helm dependency build"`)
 	f.BoolVar(&testOptions.Cleanup, "cleanup", false, "delete test pods upon completion")
 	f.BoolVar(&testOptions.Logs, "logs", false, "Dump the logs from test pods (this runs after all tests are complete, but before any cleanup)")
-	f.StringVar(&testOptions.Args, "args", "", "pass args to helm exec")
+	f.StringVar(&globalCfg.GlobalOptions.Args, "args", "", "pass args to helm exec")
 	f.IntVar(&testOptions.Timeout, "timeout", 300, "maximum time for tests to run before being considered failed")
 
 	return cmd
