@@ -5,7 +5,7 @@ import (
 	"sync"
 	"testing"
 
-	"github.com/variantdev/vals"
+	"github.com/helmfile/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
@@ -39,12 +39,17 @@ type destroyConfig struct {
 	skipDeps               bool
 	logger                 *zap.SugaredLogger
 	includeTransitiveNeeds bool
+	skipCharts             bool
 }
 
 func (d destroyConfig) Args() string {
 	return d.args
 }
 
+func (d destroyConfig) SkipCharts() bool {
+	return d.skipCharts
+}
+
 func (d destroyConfig) Interactive() bool {
 	return d.interactive
 }
