@@ -5,7 +5,7 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"github.com/variantdev/vals"
+	"github.com/helmfile/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
@@ -150,6 +150,10 @@ func (a diffConfig) ResetValues() bool {
 	return !a.reuseValues
 }
 
+func (a diffConfig) PostRenderer() string {
+	return ""
+}
+
 func TestDiff(t *testing.T) {
 	type flags struct {
 		skipNeeds    bool
