@@ -16,8 +16,11 @@ type ApplyOptions struct {
 	Output string
 	// DetailedExitcode is true if the exit code should be 2 instead of 0 if there were changes detected and the changes were synced successfully
 	DetailedExitcode bool
+
+	// TODO: Remove this function once Helmfile v0.x
 	// DEPRECATED: Use skip-cleanup instead
 	RetainValuesFiles bool
+
 	// SkipCleanup is true if the cleanup of temporary values files should be skipped
 	SkipCleanup bool
 	// SkipCRDs is true if the CRDs should be skipped
@@ -50,6 +53,8 @@ type ApplyOptions struct {
 	WaitForJobs bool
 	// ReuseValues is true if the helm command should reuse the values
 	ReuseValues bool
+	// ResetValues is true if helm command should reset values to charts' default
+	ResetValues bool
 	// Propagate '--post-renderer' to helmv3 template and helm install
 	PostRenderer string
 }
@@ -113,6 +118,7 @@ func (a *ApplyImpl) IncludeTransitiveNeeds() bool {
 	return a.ApplyOptions.IncludeTransitiveNeeds
 }
 
+// TODO: Remove this function once Helmfile v0.x
 // RetainValuesFiles returns the retain values files.
 func (a *ApplyImpl) RetainValuesFiles() bool {
 	return a.ApplyOptions.RetainValuesFiles
@@ -193,7 +199,14 @@ func (a *ApplyImpl) WaitForJobs() bool {
 
 // ReuseValues returns the ReuseValues.
 func (a *ApplyImpl) ReuseValues() bool {
-	return a.ApplyOptions.ReuseValues
+	if !a.ResetValues() {
+		return a.ApplyOptions.ReuseValues
+	}
+	return false
+}
+
+func (a *ApplyImpl) ResetValues() bool {
+	return a.ApplyOptions.ResetValues
 }
 
 // PostRenderer returns the PostRenderer.
