@@ -8,13 +8,12 @@ import (
 	"path/filepath"
 	"reflect"
 	"regexp"
+	"strings"
 	"testing"
 
 	"github.com/Masterminds/semver/v3"
 	"github.com/google/go-cmp/cmp"
 	"go.uber.org/zap"
-
-	"github.com/helmfile/helmfile/pkg/envvar"
 )
 
 // Mocking the command-line runner
@@ -29,6 +28,10 @@ func (mock *mockRunner) ExecuteStdIn(cmd string, args []string, env map[string]s
 }
 
 func (mock *mockRunner) Execute(cmd string, args []string, env map[string]string, enableLiveOutput bool) ([]byte, error) {
+	if len(mock.output) == 0 && strings.Join(args, " ") == "version --client --short" {
+		return []byte("v3.2.4+ge29ce2a"), nil
+	}
+
 	return mock.output, mock.err
 }
 
@@ -91,36 +94,12 @@ func Test_SetEnableLiveOutput(t *testing.T) {
 	}
 }
 
-func Test_SetPostRenderer(t *testing.T) {
-	helm := MockExecer(NewLogger(os.Stdout, "info"), "dev")
-	if helm.enableLiveOutput {
-		t.Error("helmexec.enableLiveOutput should not be enabled by default")
-	}
-	postRendererFoo := "/bin/rewrite-repo.sh"
-	helm.SetPostRenderer(postRendererFoo)
-	if helm.postRenderer != postRendererFoo {
-		t.Errorf("helmexec.SetPostRenderer() - actual = %s expect = %s", helm.postRenderer, postRendererFoo)
-	}
-}
-
-func Test_GetPostRenderer(t *testing.T) {
-	helm := MockExecer(NewLogger(os.Stdout, "info"), "dev")
-	if helm.enableLiveOutput {
-		t.Error("helmexec.enableLiveOutput should not be enabled by default")
-	}
-	postRendererFoo := "/bin/rewrite-repo.sh"
-	helm.SetPostRenderer(postRendererFoo)
-	if helm.GetPostRenderer() != postRendererFoo {
-		t.Errorf("helmexec.GetPostRenderer() - actual = %s expect = %s", helm.GetPostRenderer(), postRendererFoo)
-	}
-}
-
 func Test_AddRepo_Helm_3_3_2(t *testing.T) {
 	var buffer bytes.Buffer
 	logger := NewLogger(&buffer, "debug")
 	helm := &execer{
 		helmBinary:  "helm",
-		version:     *semver.MustParse("3.3.2"),
+		version:     semver.MustParse("3.3.2"),
 		logger:      logger,
 		kubeContext: "dev",
 		runner:      &mockRunner{},
@@ -763,7 +742,7 @@ exec: helm --kube-context dev pull oci://repo/helm-charts --version 0.14.0 --des
 			buffer.Reset()
 			helm := &execer{
 				helmBinary:  tt.helmBin,
-				version:     *semver.MustParse(tt.helmVersion),
+				version:     semver.MustParse(tt.helmVersion),
 				logger:      logger,
 				kubeContext: "dev",
 				runner:      &mockRunner{},
@@ -812,7 +791,7 @@ exec: helm --kube-context dev chart export chart --destination path1 --untar --u
 			buffer.Reset()
 			helm := &execer{
 				helmBinary:  tt.helmBin,
-				version:     *semver.MustParse(tt.helmVersion),
+				version:     semver.MustParse(tt.helmVersion),
 				logger:      logger,
 				kubeContext: "dev",
 				runner:      &mockRunner{},
@@ -901,13 +880,6 @@ func Test_IsHelm3(t *testing.T) {
 	if !helm.IsHelm3() {
 		t.Error("helmexec.IsHelm3() - Failed to detect Helm 3")
 	}
-
-	t.Setenv(envvar.Helm3, "1")
-	helm2Runner = mockRunner{output: []byte("Client: v2.16.0+ge13bc94\n")}
-	helm = New("helm", false, NewLogger(os.Stdout, "info"), "dev", &helm2Runner)
-	if !helm.IsHelm3() {
-		t.Errorf("helmexec.IsHelm3() - Helm3 not detected when %s is set", envvar.Helm3)
-	}
 }
 
 func Test_GetPluginVersion(t *testing.T) {
@@ -1008,7 +980,7 @@ func Test_ShowChart(t *testing.T) {
 	showChartRunner := mockRunner{output: []byte("name: my-chart\nversion: 3.2.0\n")}
 	helm := &execer{
 		helmBinary:  "helm",
-		version:     *semver.MustParse("3.3.2"),
+		version:     semver.MustParse("3.3.2"),
 		logger:      NewLogger(os.Stdout, "info"),
 		kubeContext: "dev",
 		runner:      &showChartRunner,
@@ -1025,3 +997,55 @@ func Test_ShowChart(t *testing.T) {
 		t.Errorf("helmexec.ShowChart() - expected chart version was %s, received: %s", "3.2.0", metadata.Version)
 	}
 }
+
+func TestParseHelmVersion(t *testing.T) {
+	tests := []struct {
+		name    string
+		version string
+		want    *semver.Version
+		wantErr bool
+	}{
+		{
+			name:    "helm 2",
+			version: "Client: v2.16.1+ge13bc94\n",
+			want:    semver.MustParse("v2.16.1+ge13bc94"),
+			wantErr: false,
+		},
+		{
+			name:    "helm 3",
+			version: "Client: v3.2.4+ge29ce2a\n",
+			want:    semver.MustParse("v3.2.4+ge29ce2a"),
+			wantErr: false,
+		},
+		{
+			name:    "helm 3 with os arch and build info",
+			version: "Client v3.7.1+7.el8+g8f33223\n",
+			want:    semver.MustParse("v3.7.1+7.el8"),
+			wantErr: false,
+		},
+		{
+			name:    "empty version",
+			version: "",
+			want:    nil,
+			wantErr: true,
+		},
+		{
+			name:    "invalid version",
+			version: "oooooo",
+			want:    nil,
+			wantErr: true,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			got, err := parseHelmVersion(tt.version)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("parseHelmVersion() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			if !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("parseHelmVersion() = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
