@@ -42,13 +42,7 @@ func (ld *EnvironmentValuesLoader) LoadEnvironmentValues(missingFileHandler *str
 
 		switch strOrMap := entry.(type) {
 		case string:
-			urlOrPath := strOrMap
-			localPath, err := ld.remote.Locate(urlOrPath)
-			if err == nil {
-				urlOrPath = localPath
-			}
-
-			files, skipped, err := ld.storage.resolveFile(missingFileHandler, "environment values", urlOrPath)
+			files, skipped, err := ld.storage.resolveFile(missingFileHandler, "environment values", entry.(string))
 			if err != nil {
 				return nil, err
 			}
@@ -75,9 +69,7 @@ func (ld *EnvironmentValuesLoader) LoadEnvironmentValues(missingFileHandler *str
 					return nil, fmt.Errorf("failed to load environment values file \"%s\": %v\n\nOffending YAML:\n%s", f, err, bytes)
 				}
 				maps = append(maps, m)
-				if ld.logger != nil {
-					ld.logger.Debugf("envvals_loader: loaded %s:%v", strOrMap, m)
-				}
+				ld.logger.Debugf("envvals_loader: loaded %s:%v", strOrMap, m)
 			}
 		case map[interface{}]interface{}, map[string]interface{}:
 			maps = append(maps, strOrMap)
@@ -92,7 +84,7 @@ func (ld *EnvironmentValuesLoader) LoadEnvironmentValues(missingFileHandler *str
 			if err != nil {
 				return nil, err
 			}
-			if err := mergo.Merge(&result, &vals, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue); err != nil {
+			if err := mergo.Merge(&result, &vals, mergo.WithOverride); err != nil {
 				return nil, fmt.Errorf("failed to merge %v: %v", m, err)
 			}
 		}
